@@ -1,6 +1,6 @@
 package Hubot::Adapter::Irc;
 {
-  $Hubot::Adapter::Irc::VERSION = '0.1.2';
+  $Hubot::Adapter::Irc::VERSION = '0.1.3';
 }
 use Moose;
 use namespace::autoclean;
@@ -173,6 +173,11 @@ sub close {
     $self->cv->send;
 }
 
+sub exist {
+    my ( $self, $user, $nick ) = @_;
+    return $self->findUser( $user->{room}, $nick );
+}
+
 sub createUser {
     my ( $self, $channel, $from ) = @_;
     my $user = $self->userForName($from);
@@ -191,6 +196,11 @@ sub createUser {
     return $user;
 }
 
+sub findUser {
+    my ( $self, $channel, $nick ) = @_;
+    return $self->irc->nick_modes( $channel, $nick );
+}
+
 sub checkCanStart {
     my $self = shift;
 
