@@ -1,6 +1,6 @@
 package Hubot::Response;
 {
-  $Hubot::Response::VERSION = '0.1.2';
+  $Hubot::Response::VERSION = '0.1.3';
 }
 use Moose;
 use namespace::autoclean;
@@ -55,6 +55,11 @@ sub http {
     return $self->robot->http($url);
 }
 
+sub exist {
+    my ( $self, $nick ) = @_;
+    $self->robot->adapter->exist( $self->message->user, $nick );
+}
+
 __PACKAGE__->meta->make_immutable;
 
 1;
